<?php

declare(strict_types = 1);

namespace Drupal\webform_geoip_restriction;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\File\FileSystemInterface;
use tronovav\GeoIP2Update\Client as GeoIP2Update;

/**
 * Service to update Maxmind Database.
 */
final class UpdateMaxmindManager implements UpdateMaxmindManagerInterface {

  /**
   * Constructs an UpdateMaxmindManager object.
   */
  public function __construct(
    private readonly ConfigFactoryInterface $configFactory,
    private readonly FileSystemInterface $fileSystem,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function updMaxmind(): bool|array {
    $editions = ['GeoLite2-Country'];
    $publicDir = $this->fileSystem->realpath('public://');
    // Configuration.
    $client = new GeoIP2Update([
      'license_key' => $this->configFactory->get('webform_geoip_restriction.settings')->get('maxmind_license'),
      'dir' => $publicDir,
      'editions' => $editions,
    ]);
    // Run update.
    $client->run();
    if ($client->errors()) {
      return $client->errors();
    }
    else {
      foreach ($editions as $edition) {
        rename($publicDir . '/' . $edition . '/' . $edition . '.mmdb', $publicDir . '/' . $edition . '.mmdb');
        $files = array_diff(scandir($publicDir . '/' . $edition), ['.', '..']);
        foreach ($files as $file) {
          unlink($publicDir . '/' . $edition . '/' . $file);
        }
        rmdir($publicDir . '/' . $edition);
      }
      return TRUE;
    }
  }

}
